# Sync for Expenses

Embedded accounting integrations for corporate card providers.

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install codat-sync-for-expenses
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import codatsyncexpenses
from codatsyncexpenses.models import operations

s = codatsyncexpenses.CodatSyncExpenses(
    security=shared.Security(
        auth_header="YOUR_API_KEY_HERE",
    ),
)


req = operations.GetCompanyConfigurationRequest(
    company_id="8a210b68-6988-11ed-a1eb-0242ac120002",
)

res = s.configuration.get_company_configuration(req)

if res.company_configuration is not None:
    # handle response
```
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
## Available Resources and Operations


### [configuration](docs/configuration/README.md)

* [get_company_configuration](docs/configuration/README.md#get_company_configuration) - Get company configuration
* [save_company_configuration](docs/configuration/README.md#save_company_configuration) - Set company configuration

### [connections](docs/connections/README.md)

* [create_partner_expense_connection](docs/connections/README.md#create_partner_expense_connection) - Create Partner Expense connection

### [expenses](docs/expenses/README.md)

* [create_expense_dataset](docs/expenses/README.md#create_expense_dataset) - Create expense-transactions
* [upload_attachment](docs/expenses/README.md#upload_attachment) - Upload attachment

### [mapping_options](docs/mappingoptions/README.md)

* [get_mapping_options](docs/mappingoptions/README.md#get_mapping_options) - Mapping options

### [sync](docs/sync/README.md)

* [intiate_sync](docs/sync/README.md#intiate_sync) - Initiate sync

### [sync_status](docs/syncstatus/README.md)

* [get_last_successful_sync](docs/syncstatus/README.md#get_last_successful_sync) - Last successful sync
* [get_latest_sync](docs/syncstatus/README.md#get_latest_sync) - Latest sync status
* [get_sync_by_id](docs/syncstatus/README.md#get_sync_by_id) - Get Sync status
* [list_syncs](docs/syncstatus/README.md#list_syncs) - List sync statuses

### [transaction_status](docs/transactionstatus/README.md)

* [get_sync_transaction](docs/transactionstatus/README.md#get_sync_transaction) - Get Sync Transaction
* [list_sync_transactions](docs/transactionstatus/README.md#list_sync_transactions) - Get Sync transactions
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
